/* perfSYN_demo, Version 1.0.
 * 
 * Copyright Vladimir Shakhov 2011
 * Distributed under the rules of SB RAS Algorithms&Programmes Fund, 
 * for details see http://fap.sbras.ru
 *
 * The code demonstrates an algorithm for server reliability estimating under SYN flooding.  
 * The algorithm is developed within a project supported by the Russian Foundation for Basic Research (grant 11-07-00183)
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT 
 * SHALL THE AUTHOR  OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES, CLAIMS 
 * OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, 
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 * 
 * 
 * Contact persons: shakhov@rav.sscc.ru
 */

#include "stdafx.h"
#include <iostream>


double LossRate(double r, int m)
{
		         double s = 1.0;
				 for (int j = 1; j <= m; j++)
					{
						s = 1.0 + double(j)*s/r;
					}
				 s = 1.0/s;
				 return s;
}


int main()
{
	double IoL = 10.0;        // the intensity of legal traffic 
	double spI = 1000.0;     // the spoofed traffic intensity 
    
    double type1 = 0.01;      // the probability of legal packet filtering
	double type2 = 0.2;       // the probability of spoofed packet non-filtering
    
	double mTL = 0.1;        // expectation of legal packet stay duration in backlog
	double timeout = 3.0;     
	double accuracy = 0.0001;
    
    double load = mTL * IoL * type1 + timeout * spI * (1 - type2); //estimated offered load

	int size = 1024; //backlog queue size
    
	double p;

	if (load > size + 1.0/accuracy) p = 1.0 - double(size)/load;
	else p = LossRate(load, size);

	std::cout << "Loss Rate is " << p*100.0 << "  %"  << std::endl <<std::endl;

	return 0;
}

